@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Role::Service;
 BEGIN {
-  $Bread::Board::Declare::Role::Service::VERSION = '0.06';
+  $Bread::Board::Declare::Role::Service::VERSION = '0.07';
 }
 use Moose::Role;
 # ABSTRACT: role for Bread::Board::Service objects
@@ -60,7 +60,7 @@ Bread::Board::Declare::Role::Service - role for Bread::Board::Service objects
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -84,13 +84,11 @@ contained in.
 
 =head1 SEE ALSO
 
-Please see those modules/websites for more information related to this module.
-
 =over 4
 
 =item *
 
-L<Bread::Board::Declare|Bread::Board::Declare>
+L<Bread::Board::Declare>
 
 =back
 
